@@ -79,7 +79,10 @@ sub initialize {
 
     # share_root can't keep empty dirs, we have to create them manually
     for (qw/scripts sources/) {
-        mkdir catdir( $dir, $_ );
+        my $sub_dir = catdir( $dir, $_ );
+        mkdir $sub_dir;
+        open my $fh, '>', catfile( $sub_dir, '.exists' ) or confess $!;
+        close $fh;
     }
     chmod 0644, catfile( $dir, 't', 'test' );
 
@@ -94,7 +97,7 @@ sub _install_module_build {
     my $dir = shift;
     my $module_build_path = catdir( $dir, 'inc', 'Module', );
     mkpath catdir( $module_build_path, 'Build' );
-    copy( catdir( Module::Info->new_from_module('Module::Build')->file),
+    copy( Module::Info->new_from_module('Module::Build')->file,
             $module_build_path ) or confess "copy Module/Build.pm failed: $!";
     dircopy(
         catdir(
@@ -136,7 +139,7 @@ import a dist.
 
 sub import {
     my $self = shift;
-    return unless @_;
+    return unless ref $self; # get rid of class->import
     my %args = @_;
     my $name = $args{source};
     $name =~ s{.*/}{};
@@ -854,7 +857,7 @@ sub has_branch_support {
     return;
 }
 
-*_cmd = *_update_file = *_subclass_method;
+*_cmd = *_update_file = *_update_dir = *_subclass_method;
 
 =back
 
